@@ -1,14 +1,21 @@
-from .commands.expand_meta import ExpandMeta
-from .commands.bake import Bake
 from traitlets.config import Application
 
+from .commands.bake import Bake
+from .commands.expand_meta import ExpandMeta
+
 
 class App(Application):
+    """
+    Pangeo Forge Runner CLI
+
+    Primariily used to launch various subcommands
+    """
+
     raise_config_file_errors = True
 
     subcommands = {
-        'expand-meta': (ExpandMeta, "Expand meta.yaml of a config file"),
-        'bake': (Bake, 'Bake a pangeo-forge recipe with a given Bakery')
+        "expand-meta": (ExpandMeta, "Expand meta.yaml of a config file"),
+        "bake": (Bake, "Bake a pangeo-forge recipe with a given Bakery"),
     }
 
     def start(self):
@@ -18,4 +25,4 @@ class App(Application):
 
 def main():
     app = App()
-    app.start()
\ No newline at end of file
+    app.start()
