@@ -2,11 +2,15 @@ import contextlib
 import logging
 import sys
 
+
 class LoggingStream:
     """
-    Redirect a stream (stdout / stderr) to a python logger
+    File-like object that redirects to a python logger.
+
+    Minimal implementation used only to replace sys.stdout, stderr.
     """
-    def __init__(self, log: logging.Logger, level, extra: dict):
+
+    def __init__(self, log: logging.Logger, level: str, extra: dict):
         self.log = log
         self.level = level
         self.extra = extra
@@ -34,4 +38,4 @@ def redirect_stderr(log: logging.Logger, extra: dict):
     try:
         yield
     finally:
-        sys.stderr = original_stderr
\ No newline at end of file
+        sys.stderr = original_stderr
